@@ -12,9 +12,10 @@
 
 module Bluefin.Internal where
 
-import qualified Bluefin.Internal.Exception.Scoped as ScopedException
+import Bluefin.Internal.Exception.Scoped qualified as ScopedException
 import Bluefin.Internal.OneWayCoercible
   ( OneWayCoercible (oneWayCoercibleImpl),
+    OneWayCoercibleD,
     OneWayCoercion,
     gOneWayCoercible,
     oneWayCoerce,
@@ -22,15 +23,15 @@ import Bluefin.Internal.OneWayCoercible
     oneWayCoercible,
     unsafeOneWayCoercible,
   )
-import qualified Control.Concurrent.Async as Async
+import Control.Concurrent.Async qualified as Async
 import Control.Concurrent.MVar (newEmptyMVar, putMVar, takeMVar)
-import qualified Control.Exception
+import Control.Exception qualified
 import Control.Monad (forever)
 import Control.Monad.Base (MonadBase (liftBase))
 import Control.Monad.IO.Class (MonadIO, liftIO)
 import Control.Monad.IO.Unlift (MonadUnliftIO, withRunInIO)
 import Control.Monad.Trans.Control (MonadBaseControl, StM, liftBaseWith, restoreM)
-import qualified Control.Monad.Trans.Reader as Reader
+import Control.Monad.Trans.Reader qualified as Reader
 import Data.Coerce (coerce)
 import Data.Foldable (for_)
 import Data.IORef (IORef, newIORef, readIORef, writeIORef)
@@ -400,6 +401,7 @@ type Consume a = Coroutine () a
 -- @
 class Handle (h :: Effects -> Type) where
   {-# MINIMAL handleImpl | mapHandle #-}
+
   -- | Define @handleImpl@ using 'handleMapHandle'.
   handleImpl :: HandleD h
   handleImpl = MkHandleD mapHandle
@@ -414,7 +416,7 @@ class Handle (h :: Effects -> Type) where
   --
   -- @
   -- instance Handle MyHandle where
-  --   mapHandle h = \<definition\>
+  --   mapHandle h = \<mapHandle definition\>
   -- @
   --
   -- you should change it to
@@ -422,10 +424,10 @@ class Handle (h :: Effects -> Type) where
   -- @
   -- data MyHandle e = ...
   --   deriving (Generic)
-  --   deriving (Handle) via OneWayCoercibleHandle MyHandle
+  --   deriving (Handle) via 'OneWayCoercibleHandle' MyHandle
   --
-  -- instance (e :> es) => OneWayCoercible (MyHandle e) (MyHandle es) where
-  --   oneWayCoercibleImpl = gOneWayCoercible
+  -- instance (e :> es) => 'OneWayCoercible' (MyHandle e) (MyHandle es) where
+  --   'oneWayCoercibleImpl' = 'gOneWayCoercible'
   -- @
   --
   -- If that doesn't work for any reason you can always reuse your old
@@ -437,13 +439,14 @@ class Handle (h :: Effects -> Type) where
   --
   -- @
   -- instance Handle MyHandle where
-  --   handleImpl = handleMapHandle $ \\h -> \<definition\>
+  --   handleImpl = handleMapHandle $ \\h -> \<mapHandle definition\>
   -- @
   mapHandle :: (e :> es) => h e -> h es
   mapHandle = case handleImpl of MkHandleD f -> f
 
 -- | The type of the 'handleImpl' method of the 'Handle' class.
 -- Create a @HandleD@ using 'handleMapHandle'.
+type HandleD :: (Effects -> Type) -> Type
 newtype HandleD h = MkHandleD (forall e es. (e :> es) => h e -> h es)
 
 -- | For defining the 'handleImpl' method of the 'Handle' class.
@@ -454,6 +457,7 @@ handleMapHandle ::
 handleMapHandle = MkHandleD
 
 handleOneWayCoercible ::
+  forall h.
   (forall e es. (e :> es) => OneWayCoercible (h e) (h es)) =>
   -- | ͘
   HandleD h
@@ -474,6 +478,15 @@ instance (Handle h) => Handle (M1 i t h) where
 instance (Handle h1, Handle h2) => Handle (h1 :*: h2) where
   handleImpl = handleMapHandle $ \(h1 :*: h2) -> mapHandle h1 :*: mapHandle h2
 
+oneWayCoercibleTrustMe ::
+  (e :> es) =>
+  (forall e' es'. (e' :> es') => h e' -> h es') ->
+  -- | ͘
+  OneWayCoercibleD (h e) (h es)
+-- Forcing the argument doesn't do much of a check, but it is
+-- something
+oneWayCoercibleTrustMe !_ = unsafeOneWayCoercible
+
 -- { OneWayCoercibleHandle
 
 -- | 'OneWayCoercibleHandle' is used to derive 'Handle' instances
